@@ -53,6 +53,7 @@ def download(
         logger.info("Downloading from {} ...".format(url))
         if progress:
             import tqdm
+            # todo: change tqdm to rich for download progress
 
             def hook(t: tqdm.tqdm) -> Callable[[int, int, Optional[int]], None]:
                 last_b = [0]
@@ -593,7 +594,8 @@ class ImageSourceIter(SourceIter):
         self._index_sources()
         self.is_written = False
         assert len(self.srcs) > 0, "srcs indexed empty: {}".format(self.srcs)
-        if self.video_mode or self.webcam_mode:
+        if self.video_mode and not self.webcam_mode:
+            self.is_save_video_called = False
             fourcc = cv.VideoWriter_fourcc(*"XVID")
             self.video_width = int(self.cap.get(cv.CAP_PROP_FRAME_WIDTH) + 0.5)
             self.video_height = int(self.cap.get(
@@ -610,6 +612,17 @@ class ImageSourceIter(SourceIter):
                                             self.video_height)
             )
 
+    def get_new_video_writter(self, new_width, new_height, save_f=None):
+        '''
+        for users want save a video with new width and height
+        '''
+        fourcc = cv.VideoWriter_fourcc(*"XVID")
+        video_writter = cv.VideoWriter(
+            save_f, fourcc, 25.0, (new_width,
+                                   new_height)
+        )
+        return video_writter
+
     def _is_video(self, p):
         suffix = os.path.basename(p).split('.')[-1]
         if suffix in ['mp4', 'avi', 'flv', 'wmv', 'mpeg', 'mov']:
@@ -619,6 +632,7 @@ class ImageSourceIter(SourceIter):
 
     def save_res_image_or_video_frame(self, res):
         if self.video_mode:
+            self.is_save_video_called = True
             self.video_writter.write(res)
             if not self.is_written:
                 self.is_written = True
@@ -626,27 +640,35 @@ class ImageSourceIter(SourceIter):
             return NotImplementedError
 
     def _index_sources(self):
-        assert os.path.exists(self.src), f'{self.src} not exist.'
-        if os.path.isfile(self.src) and self._is_video(self.src):
-            self.video_mode = True
-            self.cap = cv.VideoCapture(self.src)
-            self.srcs = [self.src]
-        elif os.path.isfile(self.src):
-            self.srcs = [self.src]
-        elif os.path.isdir(self.src):
-            for ext in ("*.bmp", "*.png", "*.jpg"):
-                self.srcs.extend(glob.glob(os.path.join(self.src, ext)))
-            # print(self.srcs)
-        elif isinstance(self.src, int):
+        if str(self.src).isdigit():
             self.webcam_mode = True
-            self.cap = cv.VideoCapture(self.src)
+            self.video_mode = True
+            self.cap = cv.VideoCapture(int(self.src))
+            # self.cap = cv.VideoCapture(0)
             self.srcs = [self.src]
         else:
-            TypeError("{} must be dir or file".format(self.src))
+            assert os.path.exists(self.src), f'{self.src} not exist.'
+            if os.path.isfile(self.src) and self._is_video(self.src):
+                self.video_mode = True
+                self.cap = cv.VideoCapture(self.src)
+                self.srcs = [self.src]
+            elif os.path.isfile(self.src):
+                self.srcs = [self.src]
+            elif os.path.isdir(self.src):
+                for ext in ("*.bmp", "*.png", "*.jpg"):
+                    self.srcs.extend(glob.glob(os.path.join(self.src, ext)))
+                # print(self.srcs)
+            else:
+                TypeError("{} must be dir or file".format(self.src))
 
     def __del__(self) -> None:
         if self.video_mode:
             self.cap.release()
-            self.video_writter.release()
-            if self.is_written:
+            if not self.webcam_mode:
+                self.video_writter.release()
+            if self.is_written and self.is_save_video_called:
                 print('your wrote video result file should saved into: ', self.save_f)
+            else:
+                if os.path.exists(self.save_f):
+                    # clean up remove saved file.
+                    os.remove(self.save_f)
